<?php

namespace Company\CompanyStructure\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use Company\CompanyStructure\Interfaces\DepartmentRepositoryInterface;

class DepartmentPublicController extends BaseController
{
    // use DepartmentWorkflow;

    /**
     * Constructor.
     *
     * @param type \Company\Department\Interfaces\DepartmentRepositoryInterface $department
     *
     * @return type
     */
    public function __construct(DepartmentRepositoryInterface $department)
    {
        $this->repository = $department;
        parent::__construct();
    }

    /**
     * Show department's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $departments = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->setMetaTitle(trans('$company_structure::department.names'))
            ->view('company_structure::department.index')
            ->data(compact('departments'))
            ->output();
    }


    /**
     * Show department.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $department = $this->repository->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        return $this->response->setMetaTitle($$department->name . trans('company_structure::department.name'))
            ->view('company_structure::department.show')
            ->data(compact('department'))
            ->output();
    }

}
