<?php

namespace Company\CompanyStructure\Http\Controllers;

use App\Http\Controllers\PublicController as BaseController;
use Company\CompanyStructure\Interfaces\DepartmentRoleRepositoryInterface;

class DepartmentRolePublicController extends BaseController
{
    // use DepartmentRoleWorkflow;

    /**
     * Constructor.
     *
     * @param type \Company\DepartmentRole\Interfaces\DepartmentRoleRepositoryInterface $department_role
     *
     * @return type
     */
    public function __construct(DepartmentRoleRepositoryInterface $department_role)
    {
        $this->repository = $department_role;
        parent::__construct();
    }

    /**
     * Show department_role's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $department_roles = $this->repository
        ->pushCriteria(app('Litepie\Repository\Criteria\RequestCriteria'))
        ->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();


        return $this->response->setMetaTitle(trans('$company_structure::department_role.names'))
            ->view('company_structure::department_role.index')
            ->data(compact('department_roles'))
            ->output();
    }


    /**
     * Show department_role.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $department_role = $this->repository->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        return $this->response->setMetaTitle($$department_role->name . trans('company_structure::department_role.name'))
            ->view('company_structure::department_role.show')
            ->data(compact('department_role'))
            ->output();
    }

}
