<?php

namespace Company\CompanyStructure\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Company\CompanyStructure\Http\Requests\DepartmentRoleRequest;
use Company\CompanyStructure\Models\DepartmentRole;

/**
 * Admin web controller class.
 */
class DepartmentRoleWorkflowController extends BaseController
{

    /**
     * Workflow controller function for department_role.
     *
     * @param Model   $department_role
     * @param step    next step for the workflow.
     *
     * @return Response
     */

    public function putWorkflow(DepartmentRoleRequest $request, DepartmentRole $department_role, $step)
    {

        try {

            $department_role->updateWorkflow($step);

            return response()->json([
                'message'  => trans('messages.success.changed', ['Module' => trans('company_structure::department_role.name'), 'status' => trans("app.{$step}")]),
                'code'     => 204,
                'redirect' => trans_url('/admin/department_role/department_role/' . $department_role->getRouteKey()),
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/department_role/department_role/' . $department_role->getRouteKey()),
            ], 400);

        }

    }

    /**
     * Workflow controller function for department_role.
     *
     * @param Model   $department_role
     * @param step    next step for the workflow.
     * @param user    encrypted user id.
     *
     * @return Response
     */

    public function getWorkflow(DepartmentRole $department_role, $step, $user)
    {
        try {
            $user_id = decrypt($user);

            Auth::onceUsingId($user_id);

            $department_role->updateWorkflow($step);

            $data = [
                'message' => trans('messages.success.changed', ['Module' => trans('company_structure::department_role.name'), 'status' => trans("app.{$step}")]),
                'status'  => 'success',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('company_structure::admin.department_role.message', $data)->render();

        } catch (ValidationException $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b> <br /><br />' . implode('<br />', $e->validator->errors()->all()),
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('company_structure::admin.department_role.message', $data)->render();

        } catch (Exception $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b>',
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('company_structure::admin.department_role.message', $data)->render();

        }

    }
}
