<?php

namespace Company\CompanyStructure\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Company\CompanyStructure\Http\Requests\EmployeesRequest;
use Company\CompanyStructure\Models\Employees;

/**
 * Admin web controller class.
 */
class EmployeesWorkflowController extends BaseController
{

    /**
     * Workflow controller function for employees.
     *
     * @param Model   $employees
     * @param step    next step for the workflow.
     *
     * @return Response
     */

    public function putWorkflow(EmployeesRequest $request, Employees $employees, $step)
    {

        try {

            $employees->updateWorkflow($step);

            return response()->json([
                'message'  => trans('messages.success.changed', ['Module' => trans('company_structure::employees.name'), 'status' => trans("app.{$step}")]),
                'code'     => 204,
                'redirect' => trans_url('/admin/employees/employees/' . $employees->getRouteKey()),
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/employees/employees/' . $employees->getRouteKey()),
            ], 400);

        }

    }

    /**
     * Workflow controller function for employees.
     *
     * @param Model   $employees
     * @param step    next step for the workflow.
     * @param user    encrypted user id.
     *
     * @return Response
     */

    public function getWorkflow(Employees $employees, $step, $user)
    {
        try {
            $user_id = decrypt($user);

            Auth::onceUsingId($user_id);

            $employees->updateWorkflow($step);

            $data = [
                'message' => trans('messages.success.changed', ['Module' => trans('company_structure::employees.name'), 'status' => trans("app.{$step}")]),
                'status'  => 'success',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('company_structure::admin.employees.message', $data)->render();

        } catch (ValidationException $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b> <br /><br />' . implode('<br />', $e->validator->errors()->all()),
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('company_structure::admin.employees.message', $data)->render();

        } catch (Exception $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b>',
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('company_structure::admin.employees.message', $data)->render();

        }

    }
}
