<?php

namespace Company\CompanyStructure\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Company\CompanyStructure\Http\Requests\EquipmentRequest;
use Company\CompanyStructure\Models\Equipment;

/**
 * Admin web controller class.
 */
class EquipmentWorkflowController extends BaseController
{

    /**
     * Workflow controller function for equipment.
     *
     * @param Model   $equipment
     * @param step    next step for the workflow.
     *
     * @return Response
     */

    public function putWorkflow(EquipmentRequest $request, Equipment $equipment, $step)
    {

        try {

            $equipment->updateWorkflow($step);

            return response()->json([
                'message'  => trans('messages.success.changed', ['Module' => trans('company_structure::equipment.name'), 'status' => trans("app.{$step}")]),
                'code'     => 204,
                'redirect' => trans_url('/admin/equipment/equipment/' . $equipment->getRouteKey()),
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/equipment/equipment/' . $equipment->getRouteKey()),
            ], 400);

        }

    }

    /**
     * Workflow controller function for equipment.
     *
     * @param Model   $equipment
     * @param step    next step for the workflow.
     * @param user    encrypted user id.
     *
     * @return Response
     */

    public function getWorkflow(Equipment $equipment, $step, $user)
    {
        try {
            $user_id = decrypt($user);

            Auth::onceUsingId($user_id);

            $equipment->updateWorkflow($step);

            $data = [
                'message' => trans('messages.success.changed', ['Module' => trans('company_structure::equipment.name'), 'status' => trans("app.{$step}")]),
                'status'  => 'success',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('company_structure::admin.equipment.message', $data)->render();

        } catch (ValidationException $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b> <br /><br />' . implode('<br />', $e->validator->errors()->all()),
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('company_structure::admin.equipment.message', $data)->render();

        } catch (Exception $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b>',
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('company_structure::admin.equipment.message', $data)->render();

        }

    }
}
