<?php

namespace Company\CompanyStructure\Policies;

use Litepie\User\Contracts\UserPolicy;
use Company\CompanyStructure\Models\Department;

class DepartmentPolicy
{

    /**
     * Determine if the given user can view the department.
     *
     * @param UserPolicy $user
     * @param Department $department
     *
     * @return bool
     */
    public function view(UserPolicy $user, Department $department)
    {
        if ($user->canDo('company_structure.department.view') && $user->isAdmin()) {
            return true;
        }

        return $department->user_id == user_id() && $department->user_type == user_type();
    }

    /**
     * Determine if the given user can create a department.
     *
     * @param UserPolicy $user
     * @param Department $department
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('company_structure.department.create');
    }

    /**
     * Determine if the given user can update the given department.
     *
     * @param UserPolicy $user
     * @param Department $department
     *
     * @return bool
     */
    public function update(UserPolicy $user, Department $department)
    {
        if ($user->canDo('company_structure.department.edit') && $user->isAdmin()) {
            return true;
        }

        return $department->user_id == user_id() && $department->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given department.
     *
     * @param UserPolicy $user
     * @param Department $department
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Department $department)
    {
        return $department->user_id == user_id() && $department->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given department.
     *
     * @param UserPolicy $user
     * @param Department $department
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Department $department)
    {
        if ($user->canDo('company_structure.department.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given department.
     *
     * @param UserPolicy $user
     * @param Department $department
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Department $department)
    {
        if ($user->canDo('company_structure.department.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
