<?php

namespace Company\CompanyStructure\Policies;

use Litepie\User\Contracts\UserPolicy;
use Company\CompanyStructure\Models\DepartmentRole;

class DepartmentRolePolicy
{

    /**
     * Determine if the given user can view the department_role.
     *
     * @param UserPolicy $user
     * @param DepartmentRole $department_role
     *
     * @return bool
     */
    public function view(UserPolicy $user, DepartmentRole $department_role)
    {
        if ($user->canDo('company_structure.department_role.view') && $user->isAdmin()) {
            return true;
        }

        return $department_role->user_id == user_id() && $department_role->user_type == user_type();
    }

    /**
     * Determine if the given user can create a department_role.
     *
     * @param UserPolicy $user
     * @param DepartmentRole $department_role
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('company_structure.department_role.create');
    }

    /**
     * Determine if the given user can update the given department_role.
     *
     * @param UserPolicy $user
     * @param DepartmentRole $department_role
     *
     * @return bool
     */
    public function update(UserPolicy $user, DepartmentRole $department_role)
    {
        if ($user->canDo('company_structure.department_role.edit') && $user->isAdmin()) {
            return true;
        }

        return $department_role->user_id == user_id() && $department_role->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given department_role.
     *
     * @param UserPolicy $user
     * @param DepartmentRole $department_role
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, DepartmentRole $department_role)
    {
        return $department_role->user_id == user_id() && $department_role->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given department_role.
     *
     * @param UserPolicy $user
     * @param DepartmentRole $department_role
     *
     * @return bool
     */
    public function verify(UserPolicy $user, DepartmentRole $department_role)
    {
        if ($user->canDo('company_structure.department_role.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given department_role.
     *
     * @param UserPolicy $user
     * @param DepartmentRole $department_role
     *
     * @return bool
     */
    public function approve(UserPolicy $user, DepartmentRole $department_role)
    {
        if ($user->canDo('company_structure.department_role.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
