<?php

namespace Company\CompanyStructure\Policies;

use Litepie\User\Contracts\UserPolicy;
use Company\CompanyStructure\Models\Employees;

class EmployeesPolicy
{

    /**
     * Determine if the given user can view the employees.
     *
     * @param UserPolicy $user
     * @param Employees $employees
     *
     * @return bool
     */
    public function view(UserPolicy $user, Employees $employees)
    {
        if ($user->canDo('company_structure.employees.view') && $user->isAdmin()) {
            return true;
        }

        return $employees->user_id == user_id() && $employees->user_type == user_type();
    }

    /**
     * Determine if the given user can create a employees.
     *
     * @param UserPolicy $user
     * @param Employees $employees
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('company_structure.employees.create');
    }

    /**
     * Determine if the given user can update the given employees.
     *
     * @param UserPolicy $user
     * @param Employees $employees
     *
     * @return bool
     */
    public function update(UserPolicy $user, Employees $employees)
    {
        if ($user->canDo('company_structure.employees.edit') && $user->isAdmin()) {
            return true;
        }

        return $employees->user_id == user_id() && $employees->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given employees.
     *
     * @param UserPolicy $user
     * @param Employees $employees
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Employees $employees)
    {
        return $employees->user_id == user_id() && $employees->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given employees.
     *
     * @param UserPolicy $user
     * @param Employees $employees
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Employees $employees)
    {
        if ($user->canDo('company_structure.employees.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given employees.
     *
     * @param UserPolicy $user
     * @param Employees $employees
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Employees $employees)
    {
        if ($user->canDo('company_structure.employees.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
