<?php

namespace Company\CompanyStructure\Policies;

use Litepie\User\Contracts\UserPolicy;
use Company\CompanyStructure\Models\Equipment;

class EquipmentPolicy
{

    /**
     * Determine if the given user can view the equipment.
     *
     * @param UserPolicy $user
     * @param Equipment $equipment
     *
     * @return bool
     */
    public function view(UserPolicy $user, Equipment $equipment)
    {
        if ($user->canDo('company_structure.equipment.view') && $user->isAdmin()) {
            return true;
        }

        return $equipment->user_id == user_id() && $equipment->user_type == user_type();
    }

    /**
     * Determine if the given user can create a equipment.
     *
     * @param UserPolicy $user
     * @param Equipment $equipment
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('company_structure.equipment.create');
    }

    /**
     * Determine if the given user can update the given equipment.
     *
     * @param UserPolicy $user
     * @param Equipment $equipment
     *
     * @return bool
     */
    public function update(UserPolicy $user, Equipment $equipment)
    {
        if ($user->canDo('company_structure.equipment.edit') && $user->isAdmin()) {
            return true;
        }

        return $equipment->user_id == user_id() && $equipment->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given equipment.
     *
     * @param UserPolicy $user
     * @param Equipment $equipment
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Equipment $equipment)
    {
        return $equipment->user_id == user_id() && $equipment->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given equipment.
     *
     * @param UserPolicy $user
     * @param Equipment $equipment
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Equipment $equipment)
    {
        if ($user->canDo('company_structure.equipment.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given equipment.
     *
     * @param UserPolicy $user
     * @param Equipment $equipment
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Equipment $equipment)
    {
        if ($user->canDo('company_structure.equipment.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
