<?php

namespace Company\CompanyStructure\Policies;

use Litepie\User\Contracts\UserPolicy;
use Company\CompanyStructure\Models\Hall;

class HallPolicy
{

    /**
     * Determine if the given user can view the hall.
     *
     * @param UserPolicy $user
     * @param Hall $hall
     *
     * @return bool
     */
    public function view(UserPolicy $user, Hall $hall)
    {
        if ($user->canDo('company_structure.hall.view') && $user->isAdmin()) {
            return true;
        }

        return $hall->user_id == user_id() && $hall->user_type == user_type();
    }

    /**
     * Determine if the given user can create a hall.
     *
     * @param UserPolicy $user
     * @param Hall $hall
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('company_structure.hall.create');
    }

    /**
     * Determine if the given user can update the given hall.
     *
     * @param UserPolicy $user
     * @param Hall $hall
     *
     * @return bool
     */
    public function update(UserPolicy $user, Hall $hall)
    {
        if ($user->canDo('company_structure.hall.edit') && $user->isAdmin()) {
            return true;
        }

        return $hall->user_id == user_id() && $hall->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given hall.
     *
     * @param UserPolicy $user
     * @param Hall $hall
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Hall $hall)
    {
        return $hall->user_id == user_id() && $hall->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given hall.
     *
     * @param UserPolicy $user
     * @param Hall $hall
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Hall $hall)
    {
        if ($user->canDo('company_structure.hall.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given hall.
     *
     * @param UserPolicy $user
     * @param Hall $hall
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Hall $hall)
    {
        if ($user->canDo('company_structure.hall.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
