<?php

namespace Company\CompanyStructure\Policies;

use Litepie\User\Contracts\UserPolicy;
use Company\CompanyStructure\Models\Line;

class LinePolicy
{

    /**
     * Determine if the given user can view the line.
     *
     * @param UserPolicy $user
     * @param Line $line
     *
     * @return bool
     */
    public function view(UserPolicy $user, Line $line)
    {
        if ($user->canDo('company_structure.line.view') && $user->isAdmin()) {
            return true;
        }

        return $line->user_id == user_id() && $line->user_type == user_type();
    }

    /**
     * Determine if the given user can create a line.
     *
     * @param UserPolicy $user
     * @param Line $line
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('company_structure.line.create');
    }

    /**
     * Determine if the given user can update the given line.
     *
     * @param UserPolicy $user
     * @param Line $line
     *
     * @return bool
     */
    public function update(UserPolicy $user, Line $line)
    {
        if ($user->canDo('company_structure.line.edit') && $user->isAdmin()) {
            return true;
        }

        return $line->user_id == user_id() && $line->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given line.
     *
     * @param UserPolicy $user
     * @param Line $line
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Line $line)
    {
        return $line->user_id == user_id() && $line->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given line.
     *
     * @param UserPolicy $user
     * @param Line $line
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Line $line)
    {
        if ($user->canDo('company_structure.line.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given line.
     *
     * @param UserPolicy $user
     * @param Line $line
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Line $line)
    {
        if ($user->canDo('company_structure.line.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
