<?php

namespace Company\CompanyStructure\Providers;

use Litepie\Contracts\Workflow\Workflow as WorkflowContract;
use Litepie\Foundation\Support\Providers\WorkflowServiceProvider as ServiceProvider;

class WorkflowServiceProvider extends ServiceProvider
{
    /**
     * The validators mappings for the package.
     *
     * @var array
     */
    protected $validators = [
        // Bind Hall workflow validator
        'Company\CompanyStructure\Models\Hall' => \Company\CompanyStructure\Workflow\HallValidator::class,

        // Bind Line workflow validator
        'Company\CompanyStructure\Models\Line' => \Company\CompanyStructure\Workflow\LineValidator::class,

        // Bind Equipment workflow validator
        'Company\CompanyStructure\Models\Equipment' => \Company\CompanyStructure\Workflow\EquipmentValidator::class,

        // Bind Department workflow validator
        'Company\CompanyStructure\Models\Department' => \Company\CompanyStructure\Workflow\DepartmentValidator::class,

        // Bind Employees workflow validator
        'Company\CompanyStructure\Models\Employees' => \Company\CompanyStructure\Workflow\EmployeesValidator::class,

        // Bind DepartmentRole workflow validator
        'Company\CompanyStructure\Models\DepartmentRole' => \Company\CompanyStructure\Workflow\DepartmentRoleValidator::class,
    ];

    /**
     * The actions mappings for the package.
     *
     * @var array
     */
    protected $actions = [
        // Bind Hall workflow actions
        'Company\CompanyStructure\Models\Hall' => \Company\CompanyStructure\Workflow\HallAction::class,

        // Bind Line workflow actions
        'Company\CompanyStructure\Models\Line' => \Company\CompanyStructure\Workflow\LineAction::class,

        // Bind Equipment workflow actions
        'Company\CompanyStructure\Models\Equipment' => \Company\CompanyStructure\Workflow\EquipmentAction::class,

        // Bind Department workflow actions
        'Company\CompanyStructure\Models\Department' => \Company\CompanyStructure\Workflow\DepartmentAction::class,

        // Bind Employees workflow actions
        'Company\CompanyStructure\Models\Employees' => \Company\CompanyStructure\Workflow\EmployeesAction::class,

        // Bind DepartmentRole workflow actions
        'Company\CompanyStructure\Models\DepartmentRole' => \Company\CompanyStructure\Workflow\DepartmentRoleAction::class,
    ];

    /**
     * The notifiers mappings for the package.
     *
     * @var array
     */
    protected $notifiers = [
       // Bind Hall workflow notifiers
        'Company\CompanyStructure\Models\Hall' => \Company\CompanyStructure\Workflow\HallNotifier::class,

        // Bind Line workflow notifiers
        'Company\CompanyStructure\Models\Line' => \Company\CompanyStructure\Workflow\LineNotifier::class,

        // Bind Equipment workflow notifiers
        'Company\CompanyStructure\Models\Equipment' => \Company\CompanyStructure\Workflow\EquipmentNotifier::class,

        // Bind Department workflow notifiers
        'Company\CompanyStructure\Models\Department' => \Company\CompanyStructure\Workflow\DepartmentNotifier::class,

        // Bind Employees workflow notifiers
        'Company\CompanyStructure\Models\Employees' => \Company\CompanyStructure\Workflow\EmployeesNotifier::class,

        // Bind DepartmentRole workflow notifiers
        'Company\CompanyStructure\Models\DepartmentRole' => \Company\CompanyStructure\Workflow\DepartmentRoleNotifier::class,
    ];

    /**
     * Register any package workflow validation services.
     *
     * @param \Litepie\Contracts\Workflow\Workflow $workflow
     *
     * @return void
     */
    public function boot(WorkflowContract $workflow)
    {
        parent::registerValidators($workflow);
        parent::registerActions($workflow);
        parent::registerNotifiers($workflow);
    }
}
