<?php

namespace Company\CompanyStructure\Workflow;

use Exception;
use Litepie\Workflow\Exceptions\WorkflowActionNotPerformedException;

use Company\CompanyStructure\Models\DepartmentRole;

class DepartmentRoleAction
{
    /**
     * Perform the complete action.
     *
     * @param DepartmentRole $department_role
     *
     * @return DepartmentRole
     */
    public function complete(DepartmentRole $department_role)
    {
        try {
            $department_role->status = 'complete';
            return $department_role->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the verify action.
     *
     * @param DepartmentRole $department_role
     *
     * @return DepartmentRole
     */public function verify(DepartmentRole $department_role)
    {
        try {
            $department_role->status = 'verify';
            return $department_role->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the approve action.
     *
     * @param DepartmentRole $department_role
     *
     * @return DepartmentRole
     */public function approve(DepartmentRole $department_role)
    {
        try {
            $department_role->status = 'approve';
            return $department_role->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the publish action.
     *
     * @param DepartmentRole $department_role
     *
     * @return DepartmentRole
     */public function publish(DepartmentRole $department_role)
    {
        try {
            $department_role->status = 'publish';
            return $department_role->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the archive action.
     *
     * @param DepartmentRole $department_role
     *
     * @return DepartmentRole
     */
    public function archive(DepartmentRole $department_role)
    {
        try {
            $department_role->status = 'archive';
            return $department_role->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the unpublish action.
     *
     * @param DepartmentRole $department_role
     *
     * @return DepartmentRole
     */
    public function unpublish(DepartmentRole $department_role)
    {
        try {
            $department_role->status = 'unpublish';
            return $department_role->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }
}
