<?php

namespace Company\CompanyStructure\Workflow;

use Exception;
use Litepie\Workflow\Exceptions\WorkflowActionNotPerformedException;

use Company\CompanyStructure\Models\Employees;

class EmployeesAction
{
    /**
     * Perform the complete action.
     *
     * @param Employees $employees
     *
     * @return Employees
     */
    public function complete(Employees $employees)
    {
        try {
            $employees->status = 'complete';
            return $employees->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the verify action.
     *
     * @param Employees $employees
     *
     * @return Employees
     */public function verify(Employees $employees)
    {
        try {
            $employees->status = 'verify';
            return $employees->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the approve action.
     *
     * @param Employees $employees
     *
     * @return Employees
     */public function approve(Employees $employees)
    {
        try {
            $employees->status = 'approve';
            return $employees->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the publish action.
     *
     * @param Employees $employees
     *
     * @return Employees
     */public function publish(Employees $employees)
    {
        try {
            $employees->status = 'publish';
            return $employees->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the archive action.
     *
     * @param Employees $employees
     *
     * @return Employees
     */
    public function archive(Employees $employees)
    {
        try {
            $employees->status = 'archive';
            return $employees->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the unpublish action.
     *
     * @param Employees $employees
     *
     * @return Employees
     */
    public function unpublish(Employees $employees)
    {
        try {
            $employees->status = 'unpublish';
            return $employees->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }
}
