<?php

namespace Company\CompanyStructure\Workflow;

use Company\CompanyStructure\Models\Employees;
use Validator;

class EmployeesValidator
{

    /**
     * Determine if the given employees is valid for complete status.
     *
     * @param Employees $employees
     *
     * @return bool / Validator
     */
    public function complete(Employees $employees)
    {
        return Validator::make($employees->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given employees is valid for verify status.
     *
     * @param Employees $employees
     *
     * @return bool / Validator
     */
    public function verify(Employees $employees)
    {
        return Validator::make($employees->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given employees is valid for approve status.
     *
     * @param Employees $employees
     *
     * @return bool / Validator
     */
    public function approve(Employees $employees)
    {
        return Validator::make($employees->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given employees is valid for publish status.
     *
     * @param Employees $employees
     *
     * @return bool / Validator
     */
    public function publish(Employees $employees)
    {
        return Validator::make($employees->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given employees is valid for archive status.
     *
     * @param Employees $employees
     *
     * @return bool / Validator
     */
    public function archive(Employees $employees)
    {
        return Validator::make($employees->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given employees is valid for unpublish status.
     *
     * @param Employees $employees
     *
     * @return bool / Validator
     */
    public function unpublish(Employees $employees)
    {
        return Validator::make($employees->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
