<?php

namespace Company\CompanyStructure\Workflow;

use Exception;
use Litepie\Workflow\Exceptions\WorkflowActionNotPerformedException;

use Company\CompanyStructure\Models\Equipment;

class EquipmentAction
{
    /**
     * Perform the complete action.
     *
     * @param Equipment $equipment
     *
     * @return Equipment
     */
    public function complete(Equipment $equipment)
    {
        try {
            $equipment->status = 'complete';
            return $equipment->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the verify action.
     *
     * @param Equipment $equipment
     *
     * @return Equipment
     */public function verify(Equipment $equipment)
    {
        try {
            $equipment->status = 'verify';
            return $equipment->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the approve action.
     *
     * @param Equipment $equipment
     *
     * @return Equipment
     */public function approve(Equipment $equipment)
    {
        try {
            $equipment->status = 'approve';
            return $equipment->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the publish action.
     *
     * @param Equipment $equipment
     *
     * @return Equipment
     */public function publish(Equipment $equipment)
    {
        try {
            $equipment->status = 'publish';
            return $equipment->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the archive action.
     *
     * @param Equipment $equipment
     *
     * @return Equipment
     */
    public function archive(Equipment $equipment)
    {
        try {
            $equipment->status = 'archive';
            return $equipment->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the unpublish action.
     *
     * @param Equipment $equipment
     *
     * @return Equipment
     */
    public function unpublish(Equipment $equipment)
    {
        try {
            $equipment->status = 'unpublish';
            return $equipment->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }
}
