<?php

namespace Company\CompanyStructure\Workflow;

use Company\CompanyStructure\Models\Equipment;
use Validator;

class EquipmentValidator
{

    /**
     * Determine if the given equipment is valid for complete status.
     *
     * @param Equipment $equipment
     *
     * @return bool / Validator
     */
    public function complete(Equipment $equipment)
    {
        return Validator::make($equipment->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given equipment is valid for verify status.
     *
     * @param Equipment $equipment
     *
     * @return bool / Validator
     */
    public function verify(Equipment $equipment)
    {
        return Validator::make($equipment->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given equipment is valid for approve status.
     *
     * @param Equipment $equipment
     *
     * @return bool / Validator
     */
    public function approve(Equipment $equipment)
    {
        return Validator::make($equipment->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given equipment is valid for publish status.
     *
     * @param Equipment $equipment
     *
     * @return bool / Validator
     */
    public function publish(Equipment $equipment)
    {
        return Validator::make($equipment->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given equipment is valid for archive status.
     *
     * @param Equipment $equipment
     *
     * @return bool / Validator
     */
    public function archive(Equipment $equipment)
    {
        return Validator::make($equipment->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given equipment is valid for unpublish status.
     *
     * @param Equipment $equipment
     *
     * @return bool / Validator
     */
    public function unpublish(Equipment $equipment)
    {
        return Validator::make($equipment->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
