<?php

namespace Company\CompanyStructure\Workflow;

use Exception;
use Litepie\Workflow\Exceptions\WorkflowActionNotPerformedException;

use Company\CompanyStructure\Models\Hall;

class HallAction
{
    /**
     * Perform the complete action.
     *
     * @param Hall $hall
     *
     * @return Hall
     */
    public function complete(Hall $hall)
    {
        try {
            $hall->status = 'complete';
            return $hall->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the verify action.
     *
     * @param Hall $hall
     *
     * @return Hall
     */public function verify(Hall $hall)
    {
        try {
            $hall->status = 'verify';
            return $hall->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the approve action.
     *
     * @param Hall $hall
     *
     * @return Hall
     */public function approve(Hall $hall)
    {
        try {
            $hall->status = 'approve';
            return $hall->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the publish action.
     *
     * @param Hall $hall
     *
     * @return Hall
     */public function publish(Hall $hall)
    {
        try {
            $hall->status = 'publish';
            return $hall->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the archive action.
     *
     * @param Hall $hall
     *
     * @return Hall
     */
    public function archive(Hall $hall)
    {
        try {
            $hall->status = 'archive';
            return $hall->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the unpublish action.
     *
     * @param Hall $hall
     *
     * @return Hall
     */
    public function unpublish(Hall $hall)
    {
        try {
            $hall->status = 'unpublish';
            return $hall->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }
}
