<?php

namespace Company\CompanyStructure\Workflow;

use Exception;
use Litepie\Workflow\Exceptions\WorkflowActionNotPerformedException;

use Company\CompanyStructure\Models\Line;

class LineAction
{
    /**
     * Perform the complete action.
     *
     * @param Line $line
     *
     * @return Line
     */
    public function complete(Line $line)
    {
        try {
            $line->status = 'complete';
            return $line->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the verify action.
     *
     * @param Line $line
     *
     * @return Line
     */public function verify(Line $line)
    {
        try {
            $line->status = 'verify';
            return $line->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the approve action.
     *
     * @param Line $line
     *
     * @return Line
     */public function approve(Line $line)
    {
        try {
            $line->status = 'approve';
            return $line->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the publish action.
     *
     * @param Line $line
     *
     * @return Line
     */public function publish(Line $line)
    {
        try {
            $line->status = 'publish';
            return $line->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the archive action.
     *
     * @param Line $line
     *
     * @return Line
     */
    public function archive(Line $line)
    {
        try {
            $line->status = 'archive';
            return $line->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the unpublish action.
     *
     * @param Line $line
     *
     * @return Line
     */
    public function unpublish(Line $line)
    {
        try {
            $line->status = 'unpublish';
            return $line->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }
}
