<?php

namespace Company\CompanyStructure\Workflow;

use Company\CompanyStructure\Models\Line;
use Validator;

class LineValidator
{

    /**
     * Determine if the given line is valid for complete status.
     *
     * @param Line $line
     *
     * @return bool / Validator
     */
    public function complete(Line $line)
    {
        return Validator::make($line->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given line is valid for verify status.
     *
     * @param Line $line
     *
     * @return bool / Validator
     */
    public function verify(Line $line)
    {
        return Validator::make($line->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given line is valid for approve status.
     *
     * @param Line $line
     *
     * @return bool / Validator
     */
    public function approve(Line $line)
    {
        return Validator::make($line->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given line is valid for publish status.
     *
     * @param Line $line
     *
     * @return bool / Validator
     */
    public function publish(Line $line)
    {
        return Validator::make($line->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given line is valid for archive status.
     *
     * @param Line $line
     *
     * @return bool / Validator
     */
    public function archive(Line $line)
    {
        return Validator::make($line->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given line is valid for unpublish status.
     *
     * @param Line $line
     *
     * @return bool / Validator
     */
    public function unpublish(Line $line)
    {
        return Validator::make($line->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
